searchData={"items":[{"type":"module","title":"Phone","doc":"Phone is a real telephone number parser, that will help you get useful information from numbers.","ref":"Phone.html"},{"type":"module","title":"How to use - Phone","doc":"Very simple to use:\n    iex> Phone.parse(\"555132345678\")\n    {:ok, %{a2: \"BR\", a3: \"BRA\", country: \"Brazil\", international_code: \"55\", area_code: \"51\", number: \"32345678\", area_abbreviation: \"RS\", area_type: \"state\", area_name: \"Rio Grande do Sul\"}}","ref":"Phone.html#module-how-to-use"},{"type":"function","title":"Phone.parse/1","doc":"Parses a string or integer and returns a map with information about that number.\n\n```\n  iex> Phone.parse(\"555132345678\")\n  {:ok, %{a2: \"BR\", a3: \"BRA\", country: \"Brazil\", international_code: \"55\", area_code: \"51\", number: \"32345678\", area_abbreviation: \"RS\", area_type: \"state\", area_name: \"Rio Grande do Sul\"}}\n\n  iex> Phone.parse(\"+55(51)3234-5678\")\n  {:ok, %{a2: \"BR\", a3: \"BRA\", country: \"Brazil\", international_code: \"55\", area_code: \"51\", number: \"32345678\", area_abbreviation: \"RS\", area_type: \"state\", area_name: \"Rio Grande do Sul\"}}\n\n  iex> Phone.parse(\"55 51 3234-5678\")\n  {:ok, %{a2: \"BR\", a3: \"BRA\", country: \"Brazil\", international_code: \"55\", area_code: \"51\", number: \"32345678\", area_abbreviation: \"RS\", area_type: \"state\", area_name: \"Rio Grande do Sul\"}}\n\n  iex> Phone.parse(555132345678)\n  {:ok, %{a2: \"BR\", a3: \"BRA\", country: \"Brazil\", international_code: \"55\", area_code: \"51\", number: \"32345678\", area_abbreviation: \"RS\", area_type: \"state\", area_name: \"Rio Grande do Sul\"}}\n\n```","ref":"Phone.html#parse/1"},{"type":"function","title":"Phone.parse/2","doc":"Same as `parse/1` but the number doesn't have the international code, instead you specify country as an atom with two-letters code.\n\nFor NANP countries you can use the atom `:nanp` or two-letter codes for any country in NANP.\n\nFor United Kingdom is possible to use the more known acronym `:uk` or the official two-letter code `:gb`.\n\n```\niex> Phone.parse(\"5132345678\", :br)\n{:ok, %{a2: \"BR\", a3: \"BRA\", country: \"Brazil\", international_code: \"55\", area_code: \"51\", number: \"32345678\", area_abbreviation: \"RS\", area_type: \"state\", area_name: \"Rio Grande do Sul\"}}\n\niex> Phone.parse(\"(51)3234-5678\", :br)\n{:ok, %{a2: \"BR\", a3: \"BRA\", country: \"Brazil\", international_code: \"55\", area_code: \"51\", number: \"32345678\", area_abbreviation: \"RS\", area_type: \"state\", area_name: \"Rio Grande do Sul\"}}\n\niex> Phone.parse(\"51 3234-5678\", :br)\n{:ok, %{a2: \"BR\", a3: \"BRA\", country: \"Brazil\", international_code: \"55\", area_code: \"51\", number: \"32345678\", area_abbreviation: \"RS\", area_type: \"state\", area_name: \"Rio Grande do Sul\"}}\n\niex> Phone.parse(5132345678, :br)\n{:ok, %{a2: \"BR\", a3: \"BRA\", country: \"Brazil\", international_code: \"55\", area_code: \"51\", number: \"32345678\", area_abbreviation: \"RS\", area_type: \"state\", area_name: \"Rio Grande do Sul\"}}\n\n```","ref":"Phone.html#parse/2"},{"type":"function","title":"Phone.parse!/1","doc":"Same as `parse/1`, except it raises on error.\n\n```\niex> Phone.parse!(\"555132345678\")\n%{a2: \"BR\", a3: \"BRA\", country: \"Brazil\", international_code: \"55\", area_code: \"51\", number: \"32345678\", area_abbreviation: \"RS\", area_type: \"state\", area_name: \"Rio Grande do Sul\"}\n\niex> Phone.parse!(\"+55(51)3234-5678\")\n%{a2: \"BR\", a3: \"BRA\", country: \"Brazil\", international_code: \"55\", area_code: \"51\", number: \"32345678\", area_abbreviation: \"RS\", area_type: \"state\", area_name: \"Rio Grande do Sul\"}\n\niex> Phone.parse!(\"55 51 3234-5678\")\n%{a2: \"BR\", a3: \"BRA\", country: \"Brazil\", international_code: \"55\", area_code: \"51\", number: \"32345678\", area_abbreviation: \"RS\", area_type: \"state\", area_name: \"Rio Grande do Sul\"}\n\niex> Phone.parse!(555132345678)\n%{a2: \"BR\", a3: \"BRA\", country: \"Brazil\", international_code: \"55\", area_code: \"51\", number: \"32345678\", area_abbreviation: \"RS\", area_type: \"state\", area_name: \"Rio Grande do Sul\"}\n\n```","ref":"Phone.html#parse!/1"},{"type":"function","title":"Phone.parse!/2","doc":"Same as `parse/2`, except it raises on error.\n\n```\niex> Phone.parse!(\"5132345678\", :br)\n%{a2: \"BR\", a3: \"BRA\", country: \"Brazil\", international_code: \"55\", area_code: \"51\", number: \"32345678\", area_abbreviation: \"RS\", area_type: \"state\", area_name: \"Rio Grande do Sul\"}\n\niex> Phone.parse!(\"(51)3234-5678\", :br)\n%{a2: \"BR\", a3: \"BRA\", country: \"Brazil\", international_code: \"55\", area_code: \"51\", number: \"32345678\", area_abbreviation: \"RS\", area_type: \"state\", area_name: \"Rio Grande do Sul\"}\n\niex> Phone.parse!(\"51 3234-5678\", :br)\n%{a2: \"BR\", a3: \"BRA\", country: \"Brazil\", international_code: \"55\", area_code: \"51\", number: \"32345678\", area_abbreviation: \"RS\", area_type: \"state\", area_name: \"Rio Grande do Sul\"}\n\niex> Phone.parse!(5132345678, :br)\n%{a2: \"BR\", a3: \"BRA\", country: \"Brazil\", international_code: \"55\", area_code: \"51\", number: \"32345678\", area_abbreviation: \"RS\", area_type: \"state\", area_name: \"Rio Grande do Sul\"}\n\n```","ref":"Phone.html#parse!/2"},{"type":"function","title":"Phone.valid?/1","doc":"Returns `true` if the number can be parsed, otherwise returns `false`.\n\n```\niex> Phone.valid?(\"555132345678\")\ntrue\n\niex> Phone.valid?(\"+55(51)3234-5678\")\ntrue\n\niex> Phone.valid?(\"55 51 3234-5678\")\ntrue\n\niex> Phone.valid?(555132345678)\ntrue\n\n```","ref":"Phone.html#valid?/1"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"v0.5.11 - 2025-05-17 - Changelog","doc":"* Fix wrong alpha2 code for Jamaica.\n  * Add Norfolk Island, NF, country code.","ref":"changelog.html#v0-5-11-2025-05-17"},{"type":"extras","title":"v0.5.10 - 2024-12-29 - Changelog","doc":"* Fix duplicated area code on US states: CA, NJ.\n  * Fix compilation warnings on helper macros.","ref":"changelog.html#v0-5-10-2024-12-29"},{"type":"extras","title":"v0.5.9 - 2024-10-02 - Changelog","doc":"* Add recently updated area codes for US states: AL, CA, CO, DC, FL, IL, MO, NC, OH, OK, PA, VA.\n  * Fix incorrect code for Iceland.","ref":"changelog.html#v0-5-9-2024-10-02"},{"type":"extras","title":"v0.5.8 - 2023-09-21 - Changelog","doc":"* Fix missing AU support\n  * Add area code for US, South Carolina\n  * Add area code for US, Florida\n  * Add area code for US, Georgia","ref":"changelog.html#v0-5-8-2023-09-21"},{"type":"extras","title":"v0.5.7 - 2023-05-28 - Changelog","doc":"* Fix typespecs\n  * Add missing countries Guadaloupe(GP) and Reunion(RE),\n  * Add missing area code for IE.\n  * Add missing area code for Texas and California, US.","ref":"changelog.html#v0-5-7-2023-05-28"},{"type":"extras","title":"v0.5.6 - 2022-02-28 - Changelog","doc":"* Fix pattern match for Brazil regions: PI, PR, RS.","ref":"changelog.html#v0-5-6-2022-02-28"},{"type":"extras","title":"v0.5.5 - 2022-01-20 - Changelog","doc":"* Fix pattern match for Russia.","ref":"changelog.html#v0-5-5-2022-01-20"},{"type":"extras","title":"v0.5.4 - 2021-05-20 - Changelog","doc":"* Add new area code for US, Florida.","ref":"changelog.html#v0-5-4-2021-05-20"},{"type":"extras","title":"v0.5.3 - 2021-05-15 - Changelog","doc":"* Add support to mobile spanish phone numbers.\n  * Improve documentation.","ref":"changelog.html#v0-5-3-2021-05-15"},{"type":"extras","title":"v0.5.2 - 2020-12-29 - Changelog","doc":"* Update regex for Jamaica to support new region code.\n  * Fix typo on Saint Vincent and the Grenadines country name.","ref":"changelog.html#v0-5-2-2020-12-29"},{"type":"extras","title":"v0.5.1 - 2020-05-06 - Changelog","doc":"* Update regex for Singapore to support 10 digits number.","ref":"changelog.html#v0-5-1-2020-05-06"},{"type":"extras","title":"v0.5.0 - 2020-04-29 - Changelog","doc":"* Add support to region codes for Spain.","ref":"changelog.html#v0-5-0-2020-04-29"},{"type":"extras","title":"v0.4.11 - 2020-04-27 - Changelog","doc":"* Update regex for Belgium.","ref":"changelog.html#v0-4-11-2020-04-27"},{"type":"extras","title":"v0.4.10 - 2020-03-31 - Changelog","doc":"* Add new area codes for US, California.\n  * Update regex for Netherlands","ref":"changelog.html#v0-4-10-2020-03-31"},{"type":"extras","title":"v0.4.9 - 2020-03-12 - Changelog","doc":"* Add Vancouver missing area code","ref":"changelog.html#v0-4-9-2020-03-12"},{"type":"extras","title":"v0.4.8 - 2020-01-20 - Changelog","doc":"* Add brazilian toll free numbers","ref":"changelog.html#v0-4-8-2020-01-20"},{"type":"extras","title":"v0.4.6 - 2019-07-02 - Changelog","doc":"* Fix max length for German numbers to 11","ref":"changelog.html#v0-4-6-2019-07-02"},{"type":"extras","title":"v0.4.5 - 2019-02-21 - Changelog","doc":"* Fix Italy regex to consider 3 minimum digits and max 12","ref":"changelog.html#v0-4-5-2019-02-21"},{"type":"extras","title":"v0.4.4 - 2019-01-16 - Changelog","doc":"* Fix Australia regex\n  * Fix Ireland regex","ref":"changelog.html#v0-4-4-2019-01-16"},{"type":"extras","title":"v0.4.4 - 2019-01-16 - Changelog","doc":"* Fix United Arab Emirates parsing\n  * Fix Germany parsing\n  * Fix Brazil parsing\n  * Fix South Africa parsing\n  * Fix Pakistan parsing\n  * Fix Monaco parsing\n  * Fix Ireland parsing","ref":"changelog.html#v0-4-4-2019-01-16-1"},{"type":"extras","title":"v0.4.3 - 2018-03-24 - Changelog","doc":"* Add Idaho, New York, Pennsylvania, Texas, Washington missing area codes.\n  * Fix typo on NANP Toll Free Number module.","ref":"changelog.html#v0-4-3-2018-03-24"},{"type":"extras","title":"v0.4.2 - 2017-09-05 - Changelog","doc":"* Correct parsing for Angola numbers","ref":"changelog.html#v0-4-2-2017-09-05"},{"type":"extras","title":"v0.4.1 - 2017-06-16 - Changelog","doc":"* Add 833 toll free number to NANP","ref":"changelog.html#v0-4-1-2017-06-16"},{"type":"extras","title":"v0.4.0 - 2017-04-02 - Changelog","doc":"* Updates `Helper.Countries` and `Helper.Area` behavior\n  * Several changes to improve performance.\n  * Include `valid?/1`.\n  * Remove warning from v0.3","ref":"changelog.html#v0-4-0-2017-04-02"},{"type":"extras","title":"v0.3.10 - 2017-01-15 - Changelog","doc":"* Correct number validation for Norway.\n  * Correct Ireland area codes validation.","ref":"changelog.html#v0-3-10-2017-01-15"},{"type":"extras","title":"v0.3.9 - 2016-11-11 - Changelog","doc":"* Add and correct various area codes for NANP.\n  * Better test coverage for NANP numbers.","ref":"changelog.html#v0-3-9-2016-11-11"},{"type":"extras","title":"v0.3.8 - 2016-11-09 - Changelog","doc":"* Add 424 area code for California.\n  * Add 475 area code for Connecticut.","ref":"changelog.html#v0-3-8-2016-11-09"},{"type":"extras","title":"v0.3.7 - 2016-10-28 - Changelog","doc":"* Correct area code for Ontario - US.","ref":"changelog.html#v0-3-7-2016-10-28"},{"type":"extras","title":"v0.3.6 - 2016-08-26 - Changelog","doc":"* Correct number validation to Italy.","ref":"changelog.html#v0-3-6-2016-08-26"},{"type":"extras","title":"v0.3.5 - 2016-08-14 - Changelog","doc":"* Correct number validation to Bosnia and Herzegovina.","ref":"changelog.html#v0-3-5-2016-08-14"},{"type":"extras","title":"v0.3.4 - 2016-08-03 - Changelog","doc":"* Correct number validation to Estonia.","ref":"changelog.html#v0-3-4-2016-08-03"},{"type":"extras","title":"v0.3.3 - 2016-08-02 - Changelog","doc":"* Correct number validation to São Paulo - BR.","ref":"changelog.html#v0-3-3-2016-08-02"},{"type":"extras","title":"v0.3.2 - 2016-07-24 - Changelog","doc":"* Area codes for Brazil.\n  * Updated all regular expressions for NANP, to enforce end of line.","ref":"changelog.html#v0-3-2-2016-07-24"},{"type":"extras","title":"v0.3.1 - 2016-07-21 - Changelog","doc":"* Issues with Croatia numbers corrected.","ref":"changelog.html#v0-3-1-2016-07-21"},{"type":"extras","title":"v0.3.0 - 2016-07-10 - Changelog","doc":"* Changed `parse/2` parameters order for a better use on pipes.\n  * Added functions `parse!/1` and `parse!/2` for a direct return, and raises on error.","ref":"changelog.html#v0-3-0-2016-07-10"},{"type":"extras","title":"v0.2.1 - 2016-06-14 - Changelog","doc":"* Correct area codes for Colorado - US.","ref":"changelog.html#v0-2-1-2016-06-14"},{"type":"extras","title":"v0.2.0 - 2016-06-05 - Changelog","doc":"* Add `parse/2` to `Phone` module, so can parse phone numbers without international code but with atom identifying the country.","ref":"changelog.html#v0-2-0-2016-06-05"},{"type":"extras","title":"v0.1.0 - 2016-04-21 - Changelog","doc":"* First public release","ref":"changelog.html#v0-1-0-2016-04-21"},{"type":"extras","title":"Phone","doc":"# Phone\n\n[![Build Status](https://travis-ci.org/fcevado/phone.svg?branch=master)](https://travis-ci.org/fcevado/phone)\n[![Coverage Status](https://coveralls.io/repos/github/fcevado/phone/badge.svg?branch=master)](https://coveralls.io/github/fcevado/phone?branch=master)\n[![Module Version](https://img.shields.io/hexpm/v/phone.svg)](https://hex.pm/packages/phone)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/phone/)\n[![Total Download](https://img.shields.io/hexpm/dt/phone.svg)](https://hex.pm/packages/phone)\n[![License](https://img.shields.io/hexpm/l/phone.svg)](https://github.com/fcevado/phone/blob/master/LICENSE)\n[![Last Updated](https://img.shields.io/github/last-commit/fcevado/phone.svg)](https://github.com/fcevado/phone/commits/master)\n\nPhone number parser for telephone numbers in international standard or missing international country code, for [Elixir](http://elixir-lang.org).\n\nNote on version `0.4.0` onward: `Phone` was rebuild to increase performance, that may increase compilation time but made `Phone` 100 times faster.\n\n* [Online Documentation](https://hexdocs.pm/phone/readme.html)\n* [Hex](https://hex.pm/packages/phone)","ref":"readme.html"},{"type":"extras","title":"About - Phone","doc":"What is, what isn't and what will be about Phone:\n  1. It isn't:\n     * Intended to work as libphonenumber.\n     * Prepared to format numbers.\n     * Necessary any information about the number if in international standard.\n  2. It is:\n     * A real parser, created to extract information based only in the number.\n     * Prepared to work with numbers not only in the international standard.\n  3. It will have:\n     * Area code info for every country that numbering plan has area codes.\n\n  * Patterns:\n    * Countries without area code info:\n        ```elixir\n        %{\n          country: \"Country Name\",\n          a2: \"Alpha-2\",\n          a3: \"Alpha-3\",\n          international_code: \"1\",\n          area_code: \"yyy\",\n          number: \"xxxxxxx\"\n        }\n        ```\n\n    * Countries with area code info:\n        ```elixir\n        %{\n          country: \"Country Name\",\n          a2: \"Alpha-2 code\",\n          a3: \"Alpha-3 code\",\n          international_code: \"1\",\n          number: \"xxxxxxx\",\n          area_code: \"yyy\",\n          area_name: \"Area Name\",\n          area_type: \"state\",\n          area_abbreviation: \"AN\"\n        }\n        ```","ref":"readme.html#about"},{"type":"extras","title":"Area Codes - Phone","doc":"Countries that already has area code info:\n  * United States.\n  * Canada.\n  * Brazil.\n  * Spain.","ref":"readme.html#area-codes"},{"type":"extras","title":"Vocabulary - Phone","doc":"* a2: Alpha-2, two letters code for country names.\n  * a3: Alpha-3, three letters code for country names.\n  * NANP: North American Numbering Plan, numbering plan for countries with international code number 1.\n  * Numbering Plan: The rules and specifications of how telephone numbers works in a given country.","ref":"readme.html#vocabulary"},{"type":"extras","title":"Installation - Phone","doc":"Add to your dependencies like any other hex package:\n\n```elixir\ndefp deps do\n  [\n    {:phone, \"0.5.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"License - Phone","doc":"Copyright (c) 2016 Flávio Moreira Vieira\n\nLicensed under the Apache License, Version 2.0 (the \"License\");\nyou may not use this file except in compliance with the License.\nYou may obtain a copy of the License at [http://www.apache.org/licenses/LICENSE-2.0](http://www.apache.org/licenses/LICENSE-2.0)\n\nUnless required by applicable law or agreed to in writing, software\ndistributed under the License is distributed on an \"AS IS\" BASIS,\nWITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\nSee the License for the specific language governing permissions and\nlimitations under the License.","ref":"readme.html#license"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.1"}}